FileWithContentClass class

Provides template file contents for the base GetX Flutter project structure.

Use FileWithContentClass.filesWithContent to access the map of relative file paths to their generated Dart source code.

Constructors

FileWithContentClass()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

filesWithContent Map<String, String>
A map of relative file paths to their template Dart source content.
final