folderName property
The name of the page module being scaffolded (e.g. 'home', 'splash').
Must be set before accessing subFoldersWithContent.
Implementation
static String folderName = '';
The name of the page module being scaffolded (e.g. 'home', 'splash').
Must be set before accessing subFoldersWithContent.
static String folderName = '';