SubFoldersWithContentClass class
Provides template file contents for a GetX page module's sub-folders.
Set SubFoldersWithContentClass.folderName before reading SubFoldersWithContentClass.subFoldersWithContent so that class names and import paths in the templates are correctly interpolated.
Example:
SubFoldersWithContentClass.folderName = 'home';
SubFoldersWithContentClass.subFoldersWithContent.forEach((folder, content) {
// write content to lib/pages/home/<folder>/
});
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- folderName ↔ String
-
The name of the page module being scaffolded (e.g.
'home','splash').getter/setter pair -
subFoldersWithContent
→ Map<
String, String> -
A map of sub-folder names to their template Dart source content.
final